Class: Aws::MediaPackageV2::Types::CreateHarvestJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::CreateHarvestJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The response object returned after creating a harvest job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the created harvest job.
-
#channel_group_name ⇒ String
The name of the channel group containing the channel from which content is being harvested.
-
#channel_name ⇒ String
The name of the channel from which content is being harvested.
-
#created_at ⇒ Time
The date and time the harvest job was created.
-
#description ⇒ String
The description of the harvest job, if provided.
-
#destination ⇒ Types::Destination
The S3 destination where the harvested content will be placed.
-
#error_message ⇒ String
An error message if the harvest job creation failed.
-
#etag ⇒ String
The current version of the harvest job.
-
#harvest_job_name ⇒ String
The name of the created harvest job.
-
#harvested_manifests ⇒ Types::HarvestedManifests
A list of manifests that will be harvested.
-
#modified_at ⇒ Time
The date and time the harvest job was last modified.
-
#origin_endpoint_name ⇒ String
The name of the origin endpoint from which content is being harvested.
-
#schedule_configuration ⇒ Types::HarvesterScheduleConfiguration
The configuration for when the harvest job will run, including start and end times.
-
#status ⇒ String
The current status of the harvest job (e.g., CREATED, IN_PROGRESS, ABORTED, COMPLETED, FAILED).
-
#tags ⇒ Hash<String,String>
A collection of tags associated with the harvest job.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the created harvest job.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name of the channel group containing the channel from which content is being harvested.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel from which content is being harvested.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the harvest job was created.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the harvest job, if provided.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::Destination
The S3 destination where the harvested content will be placed.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
An error message if the harvest job creation failed.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current version of the harvest job. Used for concurrency control.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#harvest_job_name ⇒ String
The name of the created harvest job.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#harvested_manifests ⇒ Types::HarvestedManifests
A list of manifests that will be harvested.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the harvest job was last modified.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name of the origin endpoint from which content is being harvested.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#schedule_configuration ⇒ Types::HarvesterScheduleConfiguration
The configuration for when the harvest job will run, including start and end times.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the harvest job (e.g., CREATED, IN_PROGRESS, ABORTED, COMPLETED, FAILED).
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of tags associated with the harvest job.
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 754 class CreateHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |