Class: Aws::MediaPackageV2::Types::CreateLowLatencyHlsManifestConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::CreateLowLatencyHlsManifestConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Create a low-latency HTTP live streaming (HLS) manifest configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#child_manifest_name ⇒ String
A short string that’s appended to the endpoint URL.
-
#filter_configuration ⇒ Types::FilterConfiguration
Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.
-
#manifest_name ⇒ String
A short short string that’s appended to the endpoint URL.
-
#manifest_window_seconds ⇒ Integer
The total duration (in seconds) of the manifest’s content.
-
#program_date_time_interval_seconds ⇒ Integer
Inserts EXT-X-PROGRAM-DATE-TIME tags in the output manifest at the interval that you specify.
-
#scte_hls ⇒ Types::ScteHls
The SCTE configuration.
-
#start_tag ⇒ Types::StartTag
To insert an EXT-X-START tag in your HLS playlist, specify a StartTag configuration object with a valid TimeOffset.
-
#uri_path_type ⇒ String
The type of path to use in manifest URIs.
-
#url_encode_child_manifest ⇒ Boolean
When enabled, MediaPackage URL-encodes the query string for API requests for LL-HLS child manifests to comply with Amazon Web Services Signature Version 4 (SigV4) signature signing protocol.
Instance Attribute Details
#child_manifest_name ⇒ String
A short string that’s appended to the endpoint URL. The child manifest name creates a unique path to this endpoint. If you don’t enter a value, MediaPackage uses the default manifest name, index, with an added suffix to distinguish it from the manifest name. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#filter_configuration ⇒ Types::FilterConfiguration
Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#manifest_name ⇒ String
A short short string that’s appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don’t enter a value, MediaPackage uses the default manifest name, index. MediaPackage automatically inserts the format extension, such as .m3u8. You can’t use the same manifest name if you use HLS manifest and low-latency HLS manifest. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#manifest_window_seconds ⇒ Integer
The total duration (in seconds) of the manifest’s content.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#program_date_time_interval_seconds ⇒ Integer
Inserts EXT-X-PROGRAM-DATE-TIME tags in the output manifest at the interval that you specify. If you don’t enter an interval, EXT-X-PROGRAM-DATE-TIME tags aren’t included in the manifest. The tags sync the stream to the wall clock so that viewers can seek to a specific time in the playback timeline on the player.
Irrespective of this parameter, if any ID3Timed metadata is in the HLS input, it is passed through to the HLS output.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#scte_hls ⇒ Types::ScteHls
The SCTE configuration.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#start_tag ⇒ Types::StartTag
To insert an EXT-X-START tag in your HLS playlist, specify a StartTag configuration object with a valid TimeOffset. When you do, you can also optionally specify whether to include a PRECISE value in the EXT-X-START tag.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#uri_path_type ⇒ String
The type of path to use in manifest URIs. ‘LEAF` uses leaf-relative paths (for example, `index_1.m3u8`). `ROOT` uses root-relative paths that include the full path from root (for example, `/out/v1/channel-group/channel/endpoint/index_1.m3u8`). If you don’t specify a value, the default is ‘LEAF`.
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#url_encode_child_manifest ⇒ Boolean
When enabled, MediaPackage URL-encodes the query string for API requests for LL-HLS child manifests to comply with Amazon Web Services Signature Version 4 (SigV4) signature signing protocol. For more information, see [Amazon Web Services Signature Version 4 for API requests] in *Identity and Access Management User Guide*.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html
932 933 934 935 936 937 938 939 940 941 942 943 944 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 932 class CreateLowLatencyHlsManifestConfiguration < Struct.new( :manifest_name, :child_manifest_name, :scte_hls, :start_tag, :manifest_window_seconds, :program_date_time_interval_seconds, :filter_configuration, :url_encode_child_manifest, :uri_path_type) SENSITIVE = [] include Aws::Structure end |