Class: Aws::MediaPackageV2::Types::DashBaseUrl
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::DashBaseUrl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The base URLs to use for retrieving segments. You can specify multiple locations and indicate the priority and weight for when each should be used, for use in mutli-CDN workflows.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dvb_priority ⇒ Integer
For use with DVB-DASH profiles only.
-
#dvb_weight ⇒ Integer
For use with DVB-DASH profiles only.
-
#service_location ⇒ String
The name of the source location.
-
#url ⇒ String
A source location for segments.
Instance Attribute Details
#dvb_priority ⇒ Integer
For use with DVB-DASH profiles only. The priority of this location for servings segments. The lower the number, the higher the priority.
1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1238 class DashBaseUrl < Struct.new( :url, :service_location, :dvb_priority, :dvb_weight) SENSITIVE = [] include Aws::Structure end |
#dvb_weight ⇒ Integer
For use with DVB-DASH profiles only. The weighting for source locations that have the same priority.
1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1238 class DashBaseUrl < Struct.new( :url, :service_location, :dvb_priority, :dvb_weight) SENSITIVE = [] include Aws::Structure end |
#service_location ⇒ String
The name of the source location.
1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1238 class DashBaseUrl < Struct.new( :url, :service_location, :dvb_priority, :dvb_weight) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
A source location for segments.
1238 1239 1240 1241 1242 1243 1244 1245 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1238 class DashBaseUrl < Struct.new( :url, :service_location, :dvb_priority, :dvb_weight) SENSITIVE = [] include Aws::Structure end |