Class: Aws::MediaPackageV2::Types::DeleteOriginEndpointPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::DeleteOriginEndpointPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
1618 1619 1620 1621 1622 1623 1624 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1618 class DeleteOriginEndpointPolicyRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
1618 1619 1620 1621 1622 1623 1624 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1618 class DeleteOriginEndpointPolicyRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.
1618 1619 1620 1621 1622 1623 1624 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1618 class DeleteOriginEndpointPolicyRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name) SENSITIVE = [] include Aws::Structure end |