Class: Aws::MediaPackageV2::Types::Encryption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::Encryption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The parameters for encrypting content.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cmaf_exclude_segment_drm_metadata ⇒ Boolean
Excludes SEIG and SGPD boxes from segment metadata in CMAF containers.
-
#constant_initialization_vector ⇒ String
A 128-bit, 16-byte hex value represented by a 32-character string, used in conjunction with the key for encrypting content.
-
#encryption_method ⇒ Types::EncryptionMethod
The encryption method to use.
-
#key_rotation_interval_seconds ⇒ Integer
The frequency (in seconds) of key changes for live workflows, in which content is streamed real time.
-
#speke_key_provider ⇒ Types::SpekeKeyProvider
The parameters for the SPEKE key provider.
Instance Attribute Details
#cmaf_exclude_segment_drm_metadata ⇒ Boolean
Excludes SEIG and SGPD boxes from segment metadata in CMAF containers.
When set to true, MediaPackage omits these DRM metadata boxes from
CMAF segments, which can improve compatibility with certain devices
and players that don't support these boxes.
Important considerations:
-
This setting only affects CMAF container formats
-
Key rotation can still be handled through media playlist signaling
-
PSSH and TENC boxes remain unaffected
-
Default behavior is preserved when this setting is disabled
Valid values: true | false
Default: false
1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1752 class Encryption < Struct.new( :constant_initialization_vector, :encryption_method, :key_rotation_interval_seconds, :cmaf_exclude_segment_drm_metadata, :speke_key_provider) SENSITIVE = [] include Aws::Structure end |
#constant_initialization_vector ⇒ String
A 128-bit, 16-byte hex value represented by a 32-character string, used in conjunction with the key for encrypting content. If you don't specify a value, then MediaPackage creates the constant initialization vector (IV).
1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1752 class Encryption < Struct.new( :constant_initialization_vector, :encryption_method, :key_rotation_interval_seconds, :cmaf_exclude_segment_drm_metadata, :speke_key_provider) SENSITIVE = [] include Aws::Structure end |
#encryption_method ⇒ Types::EncryptionMethod
The encryption method to use.
1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1752 class Encryption < Struct.new( :constant_initialization_vector, :encryption_method, :key_rotation_interval_seconds, :cmaf_exclude_segment_drm_metadata, :speke_key_provider) SENSITIVE = [] include Aws::Structure end |
#key_rotation_interval_seconds ⇒ Integer
The frequency (in seconds) of key changes for live workflows, in which content is streamed real time. The service retrieves content keys before the live content begins streaming, and then retrieves them as needed over the lifetime of the workflow. By default, key rotation is set to 300 seconds (5 minutes), the minimum rotation interval, which is equivalent to setting it to 300. If you don't enter an interval, content keys aren't rotated.
The following example setting causes the service to rotate keys
every thirty minutes: 1800
1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1752 class Encryption < Struct.new( :constant_initialization_vector, :encryption_method, :key_rotation_interval_seconds, :cmaf_exclude_segment_drm_metadata, :speke_key_provider) SENSITIVE = [] include Aws::Structure end |
#speke_key_provider ⇒ Types::SpekeKeyProvider
The parameters for the SPEKE key provider.
1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1752 class Encryption < Struct.new( :constant_initialization_vector, :encryption_method, :key_rotation_interval_seconds, :cmaf_exclude_segment_drm_metadata, :speke_key_provider) SENSITIVE = [] include Aws::Structure end |