Class: Aws::MediaPackageV2::Types::EncryptionMethod
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::EncryptionMethod
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The encryption type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cmaf_encryption_method ⇒ String
The encryption method to use.
-
#ism_encryption_method ⇒ String
The encryption method used for Microsoft Smooth Streaming (MSS) content.
-
#ts_encryption_method ⇒ String
The encryption method to use.
Instance Attribute Details
#cmaf_encryption_method ⇒ String
The encryption method to use.
1798 1799 1800 1801 1802 1803 1804 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1798 class EncryptionMethod < Struct.new( :ts_encryption_method, :cmaf_encryption_method, :ism_encryption_method) SENSITIVE = [] include Aws::Structure end |
#ism_encryption_method ⇒ String
The encryption method used for Microsoft Smooth Streaming (MSS) content. This specifies how the MSS segments are encrypted to protect the content during delivery to client players.
1798 1799 1800 1801 1802 1803 1804 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1798 class EncryptionMethod < Struct.new( :ts_encryption_method, :cmaf_encryption_method, :ism_encryption_method) SENSITIVE = [] include Aws::Structure end |
#ts_encryption_method ⇒ String
The encryption method to use.
1798 1799 1800 1801 1802 1803 1804 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1798 class EncryptionMethod < Struct.new( :ts_encryption_method, :cmaf_encryption_method, :ism_encryption_method) SENSITIVE = [] include Aws::Structure end |