Class: Aws::MediaPackageV2::Types::GetChannelPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetChannelPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
2038 2039 2040 2041 2042 2043 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2038 class GetChannelPolicyRequest < Struct.new( :channel_group_name, :channel_name) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
2038 2039 2040 2041 2042 2043 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2038 class GetChannelPolicyRequest < Struct.new( :channel_group_name, :channel_name) SENSITIVE = [] include Aws::Structure end |