Class: Aws::MediaPackageV2::Types::GetChannelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) associated with the resource.

Returns:

  • (String)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the channel was created.

Returns:

  • (Time)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description for your channel.

Returns:

  • (String)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The current Entity Tag (ETag) associated with this resource. The entity tag can be used to safely make concurrent updates to the resource.

Returns:

  • (String)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ingest_endpointsArray<Types::IngestEndpoint>

The list of ingest endpoints.

Returns:



2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#input_switch_configurationTypes::InputSwitchConfiguration

The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive. This setting is valid only when ‘InputType` is `CMAF`.



2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#input_typeString

The input type will be an immutable field which will be used to define whether the channel will allow CMAF ingest or HLS ingest. If unprovided, it will default to HLS to preserve current behavior.

The allowed values are:

  • ‘HLS` - The HLS streaming specification (which defines M3U8 manifests and TS segments).

  • ‘CMAF` - The DASH-IF CMAF Ingest specification (which defines CMAF segments with optional DASH manifests).

Returns:

  • (String)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The date and time the channel was modified.

Returns:

  • (Time)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#output_header_configurationTypes::OutputHeaderConfiguration

The settings for what common media server data (CMSD) headers AWS Elemental MediaPackage includes in responses to the CDN. This setting is valid only when ‘InputType` is `CMAF`.



2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#reset_atTime

The time that the channel was last reset.

Returns:

  • (Time)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The comma-separated list of tag key:value pairs assigned to the channel.

Returns:

  • (Hash<String,String>)


2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078

class GetChannelResponse < Struct.new(
  :arn,
  :channel_name,
  :channel_group_name,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :ingest_endpoints,
  :input_type,
  :etag,
  :tags,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end