Class: Aws::MediaPackageV2::Types::GetMssManifestConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Configuration details for a Microsoft Smooth Streaming (MSS) manifest associated with an origin endpoint. This includes all the settings and properties that define how the MSS content is packaged and delivered.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_configurationTypes::FilterConfiguration

Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.



2537
2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2537

class GetMssManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :filter_configuration,
  :manifest_window_seconds,
  :manifest_layout)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_layoutString

The layout format of the MSS manifest, which determines how the manifest is structured for client compatibility.

Returns:

  • (String)


2537
2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2537

class GetMssManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :filter_configuration,
  :manifest_window_seconds,
  :manifest_layout)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_nameString

The name of the MSS manifest. This name is appended to the origin endpoint URL to create the unique path for accessing this specific MSS manifest.

Returns:

  • (String)


2537
2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2537

class GetMssManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :filter_configuration,
  :manifest_window_seconds,
  :manifest_layout)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_window_secondsInteger

The duration (in seconds) of the manifest window. This represents the total amount of content available in the manifest at any given time.

Returns:

  • (Integer)


2537
2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2537

class GetMssManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :filter_configuration,
  :manifest_window_seconds,
  :manifest_layout)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The complete URL for accessing the MSS manifest. Client players use this URL to retrieve the manifest and begin streaming the Microsoft Smooth Streaming content.

Returns:

  • (String)


2537
2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2537

class GetMssManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :filter_configuration,
  :manifest_window_seconds,
  :manifest_layout)
  SENSITIVE = []
  include Aws::Structure
end