Class: Aws::MediaPackageV2::Types::HarvestJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::HarvestJob
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Represents a harvest job resource in MediaPackage v2, which is used to export content from an origin endpoint to an S3 bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the harvest job.
-
#channel_group_name ⇒ String
The name of the channel group containing the channel associated with this harvest job.
-
#channel_name ⇒ String
The name of the channel associated with this harvest job.
-
#created_at ⇒ Time
The date and time when the harvest job was created.
-
#description ⇒ String
An optional description of the harvest job.
-
#destination ⇒ Types::Destination
The S3 destination where the harvested content will be placed.
-
#error_message ⇒ String
An error message if the harvest job encountered any issues.
-
#etag ⇒ String
The current version of the harvest job.
-
#harvest_job_name ⇒ String
The name of the harvest job.
-
#harvested_manifests ⇒ Types::HarvestedManifests
A list of manifests that are being or have been harvested.
-
#modified_at ⇒ Time
The date and time when the harvest job was last modified.
-
#origin_endpoint_name ⇒ String
The name of the origin endpoint associated with this harvest job.
-
#schedule_configuration ⇒ Types::HarvesterScheduleConfiguration
The configuration for when the harvest job is scheduled to run.
-
#status ⇒ String
The current status of the harvest job (e.g., QUEUED, IN_PROGRESS, CANCELLED, COMPLETED, FAILED).
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the harvest job.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name of the channel group containing the channel associated with this harvest job.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel associated with this harvest job.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the harvest job was created.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description of the harvest job.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::Destination
The S3 destination where the harvested content will be placed.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
An error message if the harvest job encountered any issues.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current version of the harvest job. Used for concurrency control.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#harvest_job_name ⇒ String
The name of the harvest job.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#harvested_manifests ⇒ Types::HarvestedManifests
A list of manifests that are being or have been harvested.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time when the harvest job was last modified.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name of the origin endpoint associated with this harvest job.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#schedule_configuration ⇒ Types::HarvesterScheduleConfiguration
The configuration for when the harvest job is scheduled to run.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the harvest job (e.g., QUEUED, IN_PROGRESS, CANCELLED, COMPLETED, FAILED).
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2872 class HarvestJob < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag) SENSITIVE = [] include Aws::Structure end |