Class: Aws::MediaPackageV2::Types::InputSwitchConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::InputSwitchConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mqcs_input_switching ⇒ Boolean
When true, AWS Elemental MediaPackage performs input switching based on the MQCS.
-
#preferred_input ⇒ Integer
For CMAF inputs, indicates which input MediaPackage should prefer when both inputs have equal MQCS scores.
Instance Attribute Details
#mqcs_input_switching ⇒ Boolean
When true, AWS Elemental MediaPackage performs input switching based on the MQCS. Default is false. This setting is valid only when ‘InputType` is `CMAF`.
2971 2972 2973 2974 2975 2976 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2971 class InputSwitchConfiguration < Struct.new( :mqcs_input_switching, :preferred_input) SENSITIVE = [] include Aws::Structure end |
#preferred_input ⇒ Integer
For CMAF inputs, indicates which input MediaPackage should prefer when both inputs have equal MQCS scores. Select ‘1` to prefer the first ingest endpoint, or `2` to prefer the second ingest endpoint. If you don’t specify a preferred input, MediaPackage uses its default switching behavior when MQCS scores are equal.
2971 2972 2973 2974 2975 2976 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2971 class InputSwitchConfiguration < Struct.new( :mqcs_input_switching, :preferred_input) SENSITIVE = [] include Aws::Structure end |