Class: Aws::MediaPackageV2::Types::ResetOriginEndpointStateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name of the channel group that contains the channel with the origin endpoint that you are resetting.

Returns:

  • (String)


3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3576

class ResetOriginEndpointStateRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel with the origin endpoint that you are resetting.

Returns:

  • (String)


3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3576

class ResetOriginEndpointStateRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name)
  SENSITIVE = []
  include Aws::Structure
end

#origin_endpoint_nameString

The name of the origin endpoint that you are resetting.

Returns:

  • (String)


3576
3577
3578
3579
3580
3581
3582
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3576

class ResetOriginEndpointStateRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name)
  SENSITIVE = []
  include Aws::Structure
end