Class: Aws::MediaPackageV2::Types::ResetOriginEndpointStateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) associated with the endpoint that you just reset.

Returns:

  • (String)


3609
3610
3611
3612
3613
3614
3615
3616
3617
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609

class ResetOriginEndpointStateResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :arn,
  :reset_at)
  SENSITIVE = []
  include Aws::Structure
end

#channel_group_nameString

The name of the channel group that contains the channel with the origin endpoint that you just reset.

Returns:

  • (String)


3609
3610
3611
3612
3613
3614
3615
3616
3617
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609

class ResetOriginEndpointStateResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :arn,
  :reset_at)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel with the origin endpoint that you just reset.

Returns:

  • (String)


3609
3610
3611
3612
3613
3614
3615
3616
3617
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609

class ResetOriginEndpointStateResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :arn,
  :reset_at)
  SENSITIVE = []
  include Aws::Structure
end

#origin_endpoint_nameString

The name of the origin endpoint that you just reset.

Returns:

  • (String)


3609
3610
3611
3612
3613
3614
3615
3616
3617
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609

class ResetOriginEndpointStateResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :arn,
  :reset_at)
  SENSITIVE = []
  include Aws::Structure
end

#reset_atTime

The time that the origin endpoint was last reset.

Returns:

  • (Time)


3609
3610
3611
3612
3613
3614
3615
3616
3617
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609

class ResetOriginEndpointStateResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :arn,
  :reset_at)
  SENSITIVE = []
  include Aws::Structure
end