Class: Aws::MediaPackageV2::Types::Scte

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

The SCTE configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_ad_typesArray<String>

A list of additional non-Ad SCTE-35 event types to treat as advertisements. When configured, events matching these types produce ad markers (such as SCTE35-OUT and SCTE35-IN in HLS DATERANGE tags) in manifests.

Valid values: PROGRAM | CHAPTER | UNSCHEDULED_EVENT | ALTERNATE_CONTENT_OPPORTUNITY | NETWORK

If you don't specify any values, the default is empty (only default ad types are used).

Returns:

  • (Array<String>)


3865
3866
3867
3868
3869
3870
3871
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3865

class Scte < Struct.new(
  :scte_filter,
  :scte_in_segments,
  :custom_ad_types)
  SENSITIVE = []
  include Aws::Structure
end

#scte_filterArray<String>

The SCTE-35 message types that you want to be treated as ad markers in the output.

Returns:

  • (Array<String>)


3865
3866
3867
3868
3869
3870
3871
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3865

class Scte < Struct.new(
  :scte_filter,
  :scte_in_segments,
  :custom_ad_types)
  SENSITIVE = []
  include Aws::Structure
end

#scte_in_segmentsString

Controls whether SCTE-35 messages are included in segment files.

  • None – SCTE-35 messages are not included in segments (default)

  • All – SCTE-35 messages are embedded in segment data

  • MatchesFilter – SCTE-35 messages which match the ScteFilter are embedded in segment data

For DASH manifests, when set to All or MatchesFilter, an InbandEventStream tag signals that SCTE messages are present in segments. This setting works independently of manifest ad markers.

Returns:

  • (String)


3865
3866
3867
3868
3869
3870
3871
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3865

class Scte < Struct.new(
  :scte_filter,
  :scte_in_segments,
  :custom_ad_types)
  SENSITIVE = []
  include Aws::Structure
end