Class: Aws::MediaPackageV2::Types::Segment
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::Segment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The segment configuration, including the segment name, duration, and other configuration values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption ⇒ Types::Encryption
The parameters for encrypting content.
-
#include_iframe_only_streams ⇒ Boolean
When selected, the stream set includes an additional I-frame only stream, along with the other tracks.
-
#output_timestamp_mode ⇒ String
The output timestamp mode for the origin endpoint's segments.
-
#scte ⇒ Types::Scte
The SCTE configuration options in the segment settings.
-
#segment_duration_seconds ⇒ Integer
The duration (in seconds) of each segment.
-
#segment_name ⇒ String
The name that describes the segment.
-
#ts_include_dvb_subtitles ⇒ Boolean
By default, MediaPackage excludes all digital video broadcasting (DVB) subtitles from the output.
-
#ts_use_audio_rendition_group ⇒ Boolean
When selected, MediaPackage bundles all audio tracks in a rendition group.
Instance Attribute Details
#encryption ⇒ Types::Encryption
The parameters for encrypting content.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4014 class Segment < Struct.new( :segment_duration_seconds, :segment_name, :ts_use_audio_rendition_group, :include_iframe_only_streams, :ts_include_dvb_subtitles, :scte, :encryption, :output_timestamp_mode) SENSITIVE = [] include Aws::Structure end |
#include_iframe_only_streams ⇒ Boolean
When selected, the stream set includes an additional I-frame only stream, along with the other tracks. If false, this extra stream is not included. MediaPackage generates an I-frame only stream from the first rendition in the manifest. The service inserts EXT-I-FRAMES-ONLY tags in the output manifest, and then generates and includes an I-frames only playlist in the stream. This playlist permits player functionality like fast forward and rewind.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4014 class Segment < Struct.new( :segment_duration_seconds, :segment_name, :ts_use_audio_rendition_group, :include_iframe_only_streams, :ts_include_dvb_subtitles, :scte, :encryption, :output_timestamp_mode) SENSITIVE = [] include Aws::Structure end |
#output_timestamp_mode ⇒ String
The output timestamp mode for the origin endpoint's segments. This
setting is only configurable on channels with OutputLockingMode
set to NON_EPOCH_LOCKED. This value is immutable after endpoint
creation. If you don't specify a value, the default is
PASSTHROUGH.
The allowed values are:
-
PASSTHROUGH- Output PTS (Presentation Timestamp) values pass through unchanged from the input. -
REBASED_TO_CHANNEL_START- Output PTS is rebased relative to the channel start time.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4014 class Segment < Struct.new( :segment_duration_seconds, :segment_name, :ts_use_audio_rendition_group, :include_iframe_only_streams, :ts_include_dvb_subtitles, :scte, :encryption, :output_timestamp_mode) SENSITIVE = [] include Aws::Structure end |
#scte ⇒ Types::Scte
The SCTE configuration options in the segment settings.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4014 class Segment < Struct.new( :segment_duration_seconds, :segment_name, :ts_use_audio_rendition_group, :include_iframe_only_streams, :ts_include_dvb_subtitles, :scte, :encryption, :output_timestamp_mode) SENSITIVE = [] include Aws::Structure end |
#segment_duration_seconds ⇒ Integer
The duration (in seconds) of each segment. Enter a value equal to, or a multiple of, the input segment duration. If the value that you enter is different from the input segment duration, MediaPackage rounds segments to the nearest multiple of the input segment duration.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4014 class Segment < Struct.new( :segment_duration_seconds, :segment_name, :ts_use_audio_rendition_group, :include_iframe_only_streams, :ts_include_dvb_subtitles, :scte, :encryption, :output_timestamp_mode) SENSITIVE = [] include Aws::Structure end |
#segment_name ⇒ String
The name that describes the segment. The name is the base name of the segment used in all content manifests inside of the endpoint. You can't use spaces in the name.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4014 class Segment < Struct.new( :segment_duration_seconds, :segment_name, :ts_use_audio_rendition_group, :include_iframe_only_streams, :ts_include_dvb_subtitles, :scte, :encryption, :output_timestamp_mode) SENSITIVE = [] include Aws::Structure end |
#ts_include_dvb_subtitles ⇒ Boolean
By default, MediaPackage excludes all digital video broadcasting (DVB) subtitles from the output. When selected, MediaPackage passes through DVB subtitles into the output.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4014 class Segment < Struct.new( :segment_duration_seconds, :segment_name, :ts_use_audio_rendition_group, :include_iframe_only_streams, :ts_include_dvb_subtitles, :scte, :encryption, :output_timestamp_mode) SENSITIVE = [] include Aws::Structure end |
#ts_use_audio_rendition_group ⇒ Boolean
When selected, MediaPackage bundles all audio tracks in a rendition group. All other tracks in the stream can be used with any audio rendition from the group.
4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4014 class Segment < Struct.new( :segment_duration_seconds, :segment_name, :ts_use_audio_rendition_group, :include_iframe_only_streams, :ts_include_dvb_subtitles, :scte, :encryption, :output_timestamp_mode) SENSITIVE = [] include Aws::Structure end |