Class: Aws::MediaPackageV2::Types::SpekeKeyProvider
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::SpekeKeyProvider
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The parameters for the SPEKE key provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The ARN for the certificate that you imported to Amazon Web Services Certificate Manager to add content key encryption to this endpoint.
-
#drm_systems ⇒ Array<String>
The DRM solution provider you’re using to protect your content during distribution.
-
#encryption_contract_configuration ⇒ Types::EncryptionContractConfiguration
Configure one or more content encryption keys for your endpoints that use SPEKE Version 2.0.
-
#resource_id ⇒ String
The unique identifier for the content.
-
#role_arn ⇒ String
The ARN for the IAM role granted by the key provider that provides access to the key provider API.
-
#url ⇒ String
The URL of the API Gateway proxy that you set up to talk to your key server.
Instance Attribute Details
#certificate_arn ⇒ String
The ARN for the certificate that you imported to Amazon Web Services Certificate Manager to add content key encryption to this endpoint. For this feature to work, your DRM key provider must support content key encryption.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3911 class SpekeKeyProvider < Struct.new( :encryption_contract_configuration, :resource_id, :drm_systems, :role_arn, :url, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#drm_systems ⇒ Array<String>
The DRM solution provider you’re using to protect your content during distribution.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3911 class SpekeKeyProvider < Struct.new( :encryption_contract_configuration, :resource_id, :drm_systems, :role_arn, :url, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_contract_configuration ⇒ Types::EncryptionContractConfiguration
Configure one or more content encryption keys for your endpoints that use SPEKE Version 2.0. The encryption contract defines which content keys are used to encrypt the audio and video tracks in your stream. To configure the encryption contract, specify which audio and video encryption presets to use.
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3911 class SpekeKeyProvider < Struct.new( :encryption_contract_configuration, :resource_id, :drm_systems, :role_arn, :url, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The unique identifier for the content. The service sends this to the key server to identify the current endpoint. How unique you make this depends on how fine-grained you want access controls to be. The service does not permit you to use the same ID for two simultaneous encryption processes. The resource ID is also known as the content ID.
The following example shows a resource ID: ‘MovieNight20171126093045`
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3911 class SpekeKeyProvider < Struct.new( :encryption_contract_configuration, :resource_id, :drm_systems, :role_arn, :url, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN for the IAM role granted by the key provider that provides access to the key provider API. This role must have a trust policy that allows MediaPackage to assume the role, and it must have a sufficient permissions policy to allow access to the specific key retrieval URL. Get this from your DRM solution provider.
Valid format: ‘arn:aws:iam::accountID:role/name`. The following example shows a role ARN: `arn:aws:iam::444455556666:role/SpekeAccess`
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3911 class SpekeKeyProvider < Struct.new( :encryption_contract_configuration, :resource_id, :drm_systems, :role_arn, :url, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL of the API Gateway proxy that you set up to talk to your key server. The API Gateway proxy must reside in the same AWS Region as MediaPackage and must start with https://.
The following example shows a URL: ‘1wm2dx1f33.execute-api.us-west-2.amazonaws.com/SpekeSample/copyProtection`
3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3911 class SpekeKeyProvider < Struct.new( :encryption_contract_configuration, :resource_id, :drm_systems, :role_arn, :url, :certificate_arn) SENSITIVE = [] include Aws::Structure end |