Class: Aws::MediaPackageV2::Types::UpdateChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::UpdateChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource.
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#created_at ⇒ Time
The date and time the channel was created.
-
#description ⇒ String
The description for your channel.
-
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource.
-
#ingest_endpoints ⇒ Array<Types::IngestEndpoint>
The list of ingest endpoints.
-
#input_switch_configuration ⇒ Types::InputSwitchConfiguration
The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive.
-
#input_type ⇒ String
The input type will be an immutable field which will be used to define whether the channel will allow CMAF ingest or HLS ingest.
-
#modified_at ⇒ Time
The date and time the channel was modified.
-
#output_header_configuration ⇒ Types::OutputHeaderConfiguration
The settings for what common media server data (CMSD) headers AWS Elemental MediaPackage includes in responses to the CDN.
-
#output_locking_mode ⇒ String
The output locking mode configured for the channel.
-
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the channel.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the channel was created.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for your channel.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource. The entity tag can be used to safely make concurrent updates to the resource.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#ingest_endpoints ⇒ Array<Types::IngestEndpoint>
The list of ingest endpoints.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#input_switch_configuration ⇒ Types::InputSwitchConfiguration
The configuration for input switching based on the media quality
confidence score (MQCS) as provided from AWS Elemental MediaLive.
This setting is valid only when InputType is CMAF.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#input_type ⇒ String
The input type will be an immutable field which will be used to define whether the channel will allow CMAF ingest or HLS ingest. If unprovided, it will default to HLS to preserve current behavior.
The allowed values are:
-
HLS- The HLS streaming specification (which defines M3U8 manifests and TS segments). -
CMAF- The DASH-IF CMAF Ingest specification (which defines CMAF segments with optional DASH manifests).
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the channel was modified.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#output_header_configuration ⇒ Types::OutputHeaderConfiguration
The settings for what common media server data (CMSD) headers AWS
Elemental MediaPackage includes in responses to the CDN. This
setting is valid only when InputType is CMAF.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#output_locking_mode ⇒ String
The output locking mode configured for the channel. This value is immutable after channel creation.
The allowed values are:
-
EPOCH_LOCKED- The channel uses epoch-locked behavior with deterministic sequence numbering and fixed segment boundaries aligned to epoch time. -
NON_EPOCH_LOCKED- The channel uses non-epoch-locked behavior with duration-based segment combining and monotonically increasing sequence numbers starting from 0.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the channel.
4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4402 class UpdateChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration, :output_locking_mode) SENSITIVE = [] include Aws::Structure end |