Class: Aws::MediaPackageV2::Types::UpdateOriginEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::UpdateOriginEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#container_type ⇒ String
The type of container attached to this origin endpoint.
-
#dash_manifests ⇒ Array<Types::CreateDashManifestConfiguration>
A DASH manifest configuration.
-
#description ⇒ String
Any descriptive information that you want to add to the origin endpoint for future identification purposes.
-
#etag ⇒ String
The expected current Entity Tag (ETag) for the resource.
-
#force_endpoint_error_configuration ⇒ Types::ForceEndpointErrorConfiguration
The failover settings for the endpoint.
-
#hls_manifests ⇒ Array<Types::CreateHlsManifestConfiguration>
An HTTP live streaming (HLS) manifest configuration.
-
#low_latency_hls_manifests ⇒ Array<Types::CreateLowLatencyHlsManifestConfiguration>
A low-latency HLS manifest configuration.
-
#mss_manifests ⇒ Array<Types::CreateMssManifestConfiguration>
A list of Microsoft Smooth Streaming (MSS) manifest configurations to update for the origin endpoint.
-
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint.
-
#segment ⇒ Types::Segment
The segment configuration, including the segment name, duration, and other configuration values.
-
#startover_window_seconds ⇒ Integer
The size of the window (in seconds) to create a window of the live stream that's available for on-demand viewing.
-
#stream_name_output_mode ⇒ String
The output mode for stream names in egress manifests.
-
#uri_separator ⇒ String
The separator character to use in generated URIs for this origin endpoint.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#container_type ⇒ String
The type of container attached to this origin endpoint. A container type is a file format that encapsulates one or more media streams, such as audio and video, into a single file.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#dash_manifests ⇒ Array<Types::CreateDashManifestConfiguration>
A DASH manifest configuration.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Any descriptive information that you want to add to the origin endpoint for future identification purposes.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The expected current Entity Tag (ETag) for the resource. If the specified ETag does not match the resource's current entity tag, the update request will be rejected.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#force_endpoint_error_configuration ⇒ Types::ForceEndpointErrorConfiguration
The failover settings for the endpoint.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#hls_manifests ⇒ Array<Types::CreateHlsManifestConfiguration>
An HTTP live streaming (HLS) manifest configuration.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#low_latency_hls_manifests ⇒ Array<Types::CreateLowLatencyHlsManifestConfiguration>
A low-latency HLS manifest configuration.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#mss_manifests ⇒ Array<Types::CreateMssManifestConfiguration>
A list of Microsoft Smooth Streaming (MSS) manifest configurations to update for the origin endpoint. This replaces the existing MSS manifest configurations.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#segment ⇒ Types::Segment
The segment configuration, including the segment name, duration, and other configuration values.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#startover_window_seconds ⇒ Integer
The size of the window (in seconds) to create a window of the live stream that's available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window. The maximum startover window is 1,209,600 seconds (14 days).
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#stream_name_output_mode ⇒ String
The output mode for stream names in egress manifests. If you provide a value, it must match the current value. You can't change the stream name output mode after you create the endpoint.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |
#uri_separator ⇒ String
The separator character to use in generated URIs for this origin endpoint. This setting applies to all manifest types on the endpoint. If you don't specify a value in the update request, the current value is preserved.
4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4504 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :stream_name_output_mode, :etag) SENSITIVE = [] include Aws::Structure end |