Class: Aws::MediaPackageV2::Waiters::HarvestJobFinished

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-mediapackagev2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ HarvestJobFinished

Returns a new instance of HarvestJobFinished.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 2
  • :before_attempt (Proc)
  • :before_wait (Proc)


84
85
# File 'lib/aws-sdk-mediapackagev2/waiters.rb', line 84

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



134
135
136
# File 'lib/aws-sdk-mediapackagev2/waiters.rb', line 134

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetHarvestJobResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :channel_group_name (required, String)

    The name of the channel group containing the channel associated with the harvest job.

  • :channel_name (required, String)

    The name of the channel associated with the harvest job.

  • :origin_endpoint_name (required, String)

    The name of the origin endpoint associated with the harvest job.

  • :harvest_job_name (required, String)

    The name of the harvest job to retrieve.

Returns:



129
# File 'lib/aws-sdk-mediapackagev2/waiters.rb', line 129

def wait: (