Class: Aws::MediaPackageV2::Types::CreateDashManifestConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Create a DASH manifest configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_timeline_patternString

How MediaPackage represents the audio timeline in the DASH manifest. This setting applies DASH Segment Duration Patternization, as defined in the MPEG-DASH specification, to audio adaptation sets. When set to ‘PATTERNED`, MediaPackage uses a pattern-based segment template for audio, which reduces manifest size by expressing repeating segment durations as a pattern instead of listing each segment individually. When set to `NONE`, the manifest contains an explicit timeline that lists each audio segment.

Valid values: ‘NONE` | `PATTERNED`

For information about audio timeline patterns, see [DASH audio timeline pattern] in the *Elemental MediaPackage v2 User Guide*.

[1]: docs.aws.amazon.com/mediapackage/latest/userguide/dash-audio-timeline-pattern.html

Returns:

  • (String)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#availability_start_time_configurationTypes::DashAvailabilityStartTimeConfiguration

The configuration for the DASH ‘availabilityStartTime` attribute of the Media Presentation Description (MPD). If you don’t specify a value, MediaPackage uses the default availability start time of ‘2024-01-01T00:00:00Z`.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#base_urlsArray<Types::DashBaseUrl>

The base URLs to use for retrieving segments.

Returns:



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#compactnessString

The layout of the DASH manifest that MediaPackage produces. ‘STANDARD` indicates a default manifest, which is compacted. `NONE` indicates a full manifest.

For information about compactness, see [DASH manifest compactness] in the *Elemental MediaPackage v2 User Guide*.

[1]: docs.aws.amazon.com/mediapackage/latest/userguide/compacted.html

Returns:

  • (String)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#drm_signalingString

Determines how the DASH manifest signals the DRM content.

Returns:

  • (String)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dvb_settingsTypes::DashDvbSettings

For endpoints that use the DVB-DASH profile only. The font download and error reporting information that you want MediaPackage to pass through to the manifest.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#filter_configurationTypes::FilterConfiguration

Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_nameString

A short string that’s appended to the endpoint URL. The child manifest name creates a unique path to this endpoint.

Returns:

  • (String)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_window_secondsInteger

The total duration (in seconds) of the manifest’s content.

Returns:

  • (Integer)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#min_buffer_time_secondsInteger

Minimum amount of content (in seconds) that a player must keep available in the buffer.

Returns:

  • (Integer)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#min_update_period_secondsInteger

Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest.

Returns:

  • (Integer)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#period_triggersArray<String>

A list of triggers that controls when AWS Elemental MediaPackage separates the MPEG-DASH manifest into multiple periods. Type ‘ADS` to indicate that AWS Elemental MediaPackage must create periods in the output manifest that correspond to SCTE-35 ad markers in the input source. Leave this value empty to indicate that the manifest is contained all in one period. For more information about periods in the DASH manifest, see [Multi-period DASH in AWS Elemental MediaPackage].

[1]: docs.aws.amazon.com/mediapackage/latest/userguide/multi-period.html

Returns:

  • (Array<String>)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#profilesArray<String>

The profile that the output is compliant with.

Returns:

  • (Array<String>)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#program_informationTypes::DashProgramInformation

Details about the content that you want MediaPackage to pass through in the manifest to the playback device.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scte_dashTypes::ScteDash

The SCTE configuration.

Returns:



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#segment_template_formatString

Determines the type of variable used in the ‘media` URL of the `SegmentTemplate` tag in the manifest. Also specifies if segment timeline information is included in `SegmentTimeline` or `SegmentTemplate`.

Value description:

  • ‘NUMBER_WITH_TIMELINE` - The `$Number$` variable is used in the `media` URL. The value of this variable is the sequential number of the segment. A full `SegmentTimeline` object is presented in each `SegmentTemplate`.

^

Returns:

  • (String)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#subtitle_configurationTypes::DashSubtitleConfiguration

The configuration for DASH subtitles.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#suggested_presentation_delay_secondsInteger

The amount of time (in seconds) that the player should be from the end of the manifest.

Returns:

  • (Integer)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#uri_path_typeString

The type of path to use in manifest URIs. ‘LEAF` uses leaf-relative paths (for example, `index_1.mpd`). `ROOT` uses root-relative paths that include the full path from root (for example, `/out/v1/channel-group/channel/endpoint/index_1.mpd`). If you don’t specify a value, the default is ‘LEAF`.

Returns:

  • (String)


615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#utc_timingTypes::DashUtcTiming

Determines the type of UTC timing included in the DASH Media Presentation Description (MPD).



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 615

class CreateDashManifestConfiguration < Struct.new(
  :manifest_name,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :audio_timeline_pattern,
  :subtitle_configuration,
  :uri_path_type,
  :availability_start_time_configuration)
  SENSITIVE = []
  include Aws::Structure
end