Class: Aws::MediaPackageV2::Types::CreateDashManifestConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::CreateDashManifestConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Create a DASH manifest configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_urls ⇒ Array<Types::DashBaseUrl>
The base URLs to use for retrieving segments.
-
#compactness ⇒ String
The layout of the DASH manifest that MediaPackage produces.
-
#drm_signaling ⇒ String
Determines how the DASH manifest signals the DRM content.
-
#dvb_settings ⇒ Types::DashDvbSettings
For endpoints that use the DVB-DASH profile only.
-
#filter_configuration ⇒ Types::FilterConfiguration
Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.
-
#manifest_name ⇒ String
A short string that’s appended to the endpoint URL.
-
#manifest_window_seconds ⇒ Integer
The total duration (in seconds) of the manifest’s content.
-
#min_buffer_time_seconds ⇒ Integer
Minimum amount of content (in seconds) that a player must keep available in the buffer.
-
#min_update_period_seconds ⇒ Integer
Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest.
-
#period_triggers ⇒ Array<String>
A list of triggers that controls when AWS Elemental MediaPackage separates the MPEG-DASH manifest into multiple periods.
-
#profiles ⇒ Array<String>
The profile that the output is compliant with.
-
#program_information ⇒ Types::DashProgramInformation
Details about the content that you want MediaPackage to pass through in the manifest to the playback device.
-
#scte_dash ⇒ Types::ScteDash
The SCTE configuration.
-
#segment_template_format ⇒ String
Determines the type of variable used in the ‘media` URL of the `SegmentTemplate` tag in the manifest.
-
#subtitle_configuration ⇒ Types::DashSubtitleConfiguration
The configuration for DASH subtitles.
-
#suggested_presentation_delay_seconds ⇒ Integer
The amount of time (in seconds) that the player should be from the end of the manifest.
-
#uri_path_type ⇒ String
The type of path to use in manifest URIs.
-
#utc_timing ⇒ Types::DashUtcTiming
Determines the type of UTC timing included in the DASH Media Presentation Description (MPD).
Instance Attribute Details
#base_urls ⇒ Array<Types::DashBaseUrl>
The base URLs to use for retrieving segments.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#compactness ⇒ String
The layout of the DASH manifest that MediaPackage produces. ‘STANDARD` indicates a default manifest, which is compacted. `NONE` indicates a full manifest.
For information about compactness, see [DASH manifest compactness] in the *Elemental MediaPackage v2 User Guide*.
[1]: docs.aws.amazon.com/mediapackage/latest/userguide/compacted.html
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#drm_signaling ⇒ String
Determines how the DASH manifest signals the DRM content.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#dvb_settings ⇒ Types::DashDvbSettings
For endpoints that use the DVB-DASH profile only. The font download and error reporting information that you want MediaPackage to pass through to the manifest.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#filter_configuration ⇒ Types::FilterConfiguration
Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#manifest_name ⇒ String
A short string that’s appended to the endpoint URL. The child manifest name creates a unique path to this endpoint.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#manifest_window_seconds ⇒ Integer
The total duration (in seconds) of the manifest’s content.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#min_buffer_time_seconds ⇒ Integer
Minimum amount of content (in seconds) that a player must keep available in the buffer.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#min_update_period_seconds ⇒ Integer
Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#period_triggers ⇒ Array<String>
A list of triggers that controls when AWS Elemental MediaPackage separates the MPEG-DASH manifest into multiple periods. Type ‘ADS` to indicate that AWS Elemental MediaPackage must create periods in the output manifest that correspond to SCTE-35 ad markers in the input source. Leave this value empty to indicate that the manifest is contained all in one period. For more information about periods in the DASH manifest, see [Multi-period DASH in AWS Elemental MediaPackage].
[1]: docs.aws.amazon.com/mediapackage/latest/userguide/multi-period.html
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#profiles ⇒ Array<String>
The profile that the output is compliant with.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#program_information ⇒ Types::DashProgramInformation
Details about the content that you want MediaPackage to pass through in the manifest to the playback device.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#scte_dash ⇒ Types::ScteDash
The SCTE configuration.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#segment_template_format ⇒ String
Determines the type of variable used in the ‘media` URL of the `SegmentTemplate` tag in the manifest. Also specifies if segment timeline information is included in `SegmentTimeline` or `SegmentTemplate`.
Value description:
-
‘NUMBER_WITH_TIMELINE` - The `$Number$` variable is used in the `media` URL. The value of this variable is the sequential number of the segment. A full `SegmentTimeline` object is presented in each `SegmentTemplate`.
^
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#subtitle_configuration ⇒ Types::DashSubtitleConfiguration
The configuration for DASH subtitles.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#suggested_presentation_delay_seconds ⇒ Integer
The amount of time (in seconds) that the player should be from the end of the manifest.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#uri_path_type ⇒ String
The type of path to use in manifest URIs. ‘LEAF` uses leaf-relative paths (for example, `index_1.mpd`). `ROOT` uses root-relative paths that include the full path from root (for example, `/out/v1/channel-group/channel/endpoint/index_1.mpd`). If you don’t specify a value, the default is ‘LEAF`.
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#utc_timing ⇒ Types::DashUtcTiming
Determines the type of UTC timing included in the DASH Media Presentation Description (MPD).
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 588 class CreateDashManifestConfiguration < Struct.new( :manifest_name, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |