Class: Aws::MediaPackageV2::Types::CreateOriginEndpointResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::CreateOriginEndpointResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource.
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#container_type ⇒ String
The type of container attached to this origin endpoint.
-
#created_at ⇒ Time
The date and time the origin endpoint was created.
-
#dash_manifests ⇒ Array<Types::GetDashManifestConfiguration>
A DASH manifest configuration.
-
#description ⇒ String
The description for your origin endpoint.
-
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource.
-
#force_endpoint_error_configuration ⇒ Types::ForceEndpointErrorConfiguration
The failover settings for the endpoint.
-
#hls_manifests ⇒ Array<Types::GetHlsManifestConfiguration>
An HTTP live streaming (HLS) manifest configuration.
-
#low_latency_hls_manifests ⇒ Array<Types::GetLowLatencyHlsManifestConfiguration>
A low-latency HLS manifest configuration.
-
#modified_at ⇒ Time
The date and time the origin endpoint was modified.
-
#mss_manifests ⇒ Array<Types::GetMssManifestConfiguration>
The Microsoft Smooth Streaming (MSS) manifest configurations that were created for this origin endpoint.
-
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint.
-
#segment ⇒ Types::Segment
The segment configuration, including the segment name, duration, and other configuration values.
-
#startover_window_seconds ⇒ Integer
The size of the window (in seconds) to create a window of the live stream that’s available for on-demand viewing.
-
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the origin endpoint.
-
#uri_separator ⇒ String
The separator character used in generated URIs for this origin endpoint.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#container_type ⇒ String
The type of container attached to this origin endpoint.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the origin endpoint was created.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#dash_manifests ⇒ Array<Types::GetDashManifestConfiguration>
A DASH manifest configuration.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for your origin endpoint.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource. The entity tag can be used to safely make concurrent updates to the resource.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#force_endpoint_error_configuration ⇒ Types::ForceEndpointErrorConfiguration
The failover settings for the endpoint.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#hls_manifests ⇒ Array<Types::GetHlsManifestConfiguration>
An HTTP live streaming (HLS) manifest configuration.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#low_latency_hls_manifests ⇒ Array<Types::GetLowLatencyHlsManifestConfiguration>
A low-latency HLS manifest configuration.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the origin endpoint was modified.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#mss_manifests ⇒ Array<Types::GetMssManifestConfiguration>
The Microsoft Smooth Streaming (MSS) manifest configurations that were created for this origin endpoint.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#segment ⇒ Types::Segment
The segment configuration, including the segment name, duration, and other configuration values.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#startover_window_seconds ⇒ Integer
The size of the window (in seconds) to create a window of the live stream that’s available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the origin endpoint.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#uri_separator ⇒ String
The separator character used in generated URIs for this origin endpoint.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1190 class CreateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags) SENSITIVE = [] include Aws::Structure end |