Class: Aws::MediaPackageV2::Types::DashAvailabilityStartTimeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::DashAvailabilityStartTimeConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
DashAvailabilityStartTimeConfiguration is a union - when making an API calls you must set exactly one of the members.
DashAvailabilityStartTimeConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of DashAvailabilityStartTimeConfiguration corresponding to the set member.
The configuration for the DASH ‘availabilityStartTime` attribute of the Media Presentation Description (MPD). Use this configuration to set a custom availability start time for your DASH manifest.
Direct Known Subclasses
Defined Under Namespace
Classes: FixedAvailabilityStartTime, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fixed_availability_start_time ⇒ Time
The fixed availability start time for the DASH manifest, in ISO 8601 date-time format.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#fixed_availability_start_time ⇒ Time
The fixed availability start time for the DASH manifest, in ISO 8601 date-time format. The value must have hourly granularity, meaning that the minutes, seconds, and fractional seconds must be zero. The value must be on or after ‘2024-01-01T00:00:00Z` and must be at least 14 days before the current time.
1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1239 class DashAvailabilityStartTimeConfiguration < Struct.new( :fixed_availability_start_time, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class FixedAvailabilityStartTime < DashAvailabilityStartTimeConfiguration; end class Unknown < DashAvailabilityStartTimeConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1239 1240 1241 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1239 def unknown @unknown end |