Class: Aws::MediaPackageV2::Types::DeleteChannelGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::DeleteChannelGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1488 class DeleteChannelGroupRequest < Struct.new( :channel_group_name) SENSITIVE = [] include Aws::Structure end |