Class: Aws::MediaPackageV2::Types::DeleteChannelGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::DeleteChannelGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1430 class DeleteChannelGroupRequest < Struct.new( :channel_group_name) SENSITIVE = [] include Aws::Structure end |