Class: Aws::MediaPackageV2::Types::DeleteChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


1516
1517
1518
1519
1520
1521
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1516

class DeleteChannelRequest < Struct.new(
  :channel_group_name,
  :channel_name)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


1516
1517
1518
1519
1520
1521
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1516

class DeleteChannelRequest < Struct.new(
  :channel_group_name,
  :channel_name)
  SENSITIVE = []
  include Aws::Structure
end