Class: Aws::MediaPackageV2::Types::EncryptionMethod
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::EncryptionMethod
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The encryption type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cmaf_encryption_method ⇒ String
The encryption method to use.
-
#ism_encryption_method ⇒ String
The encryption method used for Microsoft Smooth Streaming (MSS) content.
-
#ts_encryption_method ⇒ String
The encryption method to use.
Instance Attribute Details
#cmaf_encryption_method ⇒ String
The encryption method to use.
1777 1778 1779 1780 1781 1782 1783 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1777 class EncryptionMethod < Struct.new( :ts_encryption_method, :cmaf_encryption_method, :ism_encryption_method) SENSITIVE = [] include Aws::Structure end |
#ism_encryption_method ⇒ String
The encryption method used for Microsoft Smooth Streaming (MSS) content. This specifies how the MSS segments are encrypted to protect the content during delivery to client players.
1777 1778 1779 1780 1781 1782 1783 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1777 class EncryptionMethod < Struct.new( :ts_encryption_method, :cmaf_encryption_method, :ism_encryption_method) SENSITIVE = [] include Aws::Structure end |
#ts_encryption_method ⇒ String
The encryption method to use.
1777 1778 1779 1780 1781 1782 1783 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1777 class EncryptionMethod < Struct.new( :ts_encryption_method, :cmaf_encryption_method, :ism_encryption_method) SENSITIVE = [] include Aws::Structure end |