Class: Aws::MediaPackageV2::Types::GetChannelGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetChannelGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
1896 1897 1898 1899 1900 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1896 class GetChannelGroupRequest < Struct.new( :channel_group_name) SENSITIVE = [] include Aws::Structure end |