Class: Aws::MediaPackageV2::Types::GetChannelPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1970

class GetChannelPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1970

class GetChannelPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name)
  SENSITIVE = []
  include Aws::Structure
end