Class: Aws::MediaPackageV2::Types::GetChannelPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetChannelPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1949 class GetChannelPolicyRequest < Struct.new( :channel_group_name, :channel_name) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
1949 1950 1951 1952 1953 1954 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1949 class GetChannelPolicyRequest < Struct.new( :channel_group_name, :channel_name) SENSITIVE = [] include Aws::Structure end |