Class: Aws::MediaPackageV2::Types::GetChannelPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetChannelPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#policy ⇒ String
The policy assigned to the channel.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
2063 2064 2065 2066 2067 2068 2069 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2063 class GetChannelPolicyResponse < Struct.new( :channel_group_name, :channel_name, :policy) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
2063 2064 2065 2066 2067 2068 2069 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2063 class GetChannelPolicyResponse < Struct.new( :channel_group_name, :channel_name, :policy) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The policy assigned to the channel.
2063 2064 2065 2066 2067 2068 2069 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2063 class GetChannelPolicyResponse < Struct.new( :channel_group_name, :channel_name, :policy) SENSITIVE = [] include Aws::Structure end |