Class: Aws::MediaPackageV2::Types::GetChannelPolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1995

class GetChannelPolicyResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1995

class GetChannelPolicyResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#policyString

The policy assigned to the channel.

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1995

class GetChannelPolicyResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end