Class: Aws::MediaPackageV2::Types::GetChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
1996 1997 1998 1999 2000 2001 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1996 class GetChannelRequest < Struct.new( :channel_group_name, :channel_name) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
1996 1997 1998 1999 2000 2001 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 1996 class GetChannelRequest < Struct.new( :channel_group_name, :channel_name) SENSITIVE = [] include Aws::Structure end |