Class: Aws::MediaPackageV2::Types::GetChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource.
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#created_at ⇒ Time
The date and time the channel was created.
-
#description ⇒ String
The description for your channel.
-
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource.
-
#ingest_endpoints ⇒ Array<Types::IngestEndpoint>
The list of ingest endpoints.
-
#input_switch_configuration ⇒ Types::InputSwitchConfiguration
The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive.
-
#input_type ⇒ String
The input type will be an immutable field which will be used to define whether the channel will allow CMAF ingest or HLS ingest.
-
#modified_at ⇒ Time
The date and time the channel was modified.
-
#output_header_configuration ⇒ Types::OutputHeaderConfiguration
The settings for what common media server data (CMSD) headers AWS Elemental MediaPackage includes in responses to the CDN.
-
#reset_at ⇒ Time
The time that the channel was last reset.
-
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the channel.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the channel was created.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for your channel.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource. The entity tag can be used to safely make concurrent updates to the resource.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#ingest_endpoints ⇒ Array<Types::IngestEndpoint>
The list of ingest endpoints.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#input_switch_configuration ⇒ Types::InputSwitchConfiguration
The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive. This setting is valid only when ‘InputType` is `CMAF`.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#input_type ⇒ String
The input type will be an immutable field which will be used to define whether the channel will allow CMAF ingest or HLS ingest. If unprovided, it will default to HLS to preserve current behavior.
The allowed values are:
-
‘HLS` - The HLS streaming specification (which defines M3U8 manifests and TS segments).
-
‘CMAF` - The DASH-IF CMAF Ingest specification (which defines CMAF segments with optional DASH manifests).
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the channel was modified.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#output_header_configuration ⇒ Types::OutputHeaderConfiguration
The settings for what common media server data (CMSD) headers AWS Elemental MediaPackage includes in responses to the CDN. This setting is valid only when ‘InputType` is `CMAF`.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#reset_at ⇒ Time
The time that the channel was last reset.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the channel.
2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2078 class GetChannelResponse < Struct.new( :arn, :channel_name, :channel_group_name, :created_at, :modified_at, :reset_at, :description, :ingest_endpoints, :input_type, :etag, :tags, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |