Class: Aws::MediaPackageV2::Types::GetDashManifestConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Retrieve the DASH manifest configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_urlsArray<Types::DashBaseUrl>

The base URL to use for retrieving segments.

Returns:



2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#compactnessString

The layout of the DASH manifest that MediaPackage produces. ‘STANDARD` indicates a default manifest, which is compacted. `NONE` indicates a full manifest.

Returns:

  • (String)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#drm_signalingString

Determines how the DASH manifest signals the DRM content.

Returns:

  • (String)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#dvb_settingsTypes::DashDvbSettings

For endpoints that use the DVB-DASH profile only. The font download and error reporting information that you want MediaPackage to pass through to the manifest.



2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#filter_configurationTypes::FilterConfiguration

Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.



2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_nameString

A short string that’s appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don’t enter a value, MediaPackage uses the default manifest name, index.

Returns:

  • (String)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#manifest_window_secondsInteger

The total duration (in seconds) of the manifest’s content.

Returns:

  • (Integer)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#min_buffer_time_secondsInteger

Minimum amount of content (in seconds) that a player must keep available in the buffer.

Returns:

  • (Integer)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#min_update_period_secondsInteger

Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest.

Returns:

  • (Integer)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#period_triggersArray<String>

A list of triggers that controls when AWS Elemental MediaPackage separates the MPEG-DASH manifest into multiple periods. Leave this value empty to indicate that the manifest is contained all in one period. For more information about periods in the DASH manifest, see [Multi-period DASH in AWS Elemental MediaPackage].

[1]: docs.aws.amazon.com/mediapackage/latest/userguide/multi-period.html

Returns:

  • (Array<String>)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#profilesArray<String>

The profile that the output is compliant with.

Returns:

  • (Array<String>)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#program_informationTypes::DashProgramInformation

Details about the content that you want MediaPackage to pass through in the manifest to the playback device.



2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#scte_dashTypes::ScteDash

The SCTE configuration.

Returns:



2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#segment_template_formatString

Determines the type of variable used in the ‘media` URL of the `SegmentTemplate` tag in the manifest. Also specifies if segment timeline information is included in `SegmentTimeline` or `SegmentTemplate`.

Value description:

  • ‘NUMBER_WITH_TIMELINE` - The `$Number$` variable is used in the `media` URL. The value of this variable is the sequential number of the segment. A full `SegmentTimeline` object is presented in each `SegmentTemplate`.

^

Returns:

  • (String)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#subtitle_configurationTypes::DashSubtitleConfiguration

The configuration for DASH subtitles.



2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#suggested_presentation_delay_secondsInteger

The amount of time (in seconds) that the player should be from the end of the manifest.

Returns:

  • (Integer)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#uri_path_typeString

The type of path used in manifest URIs. ‘LEAF` indicates leaf-relative paths. `ROOT` indicates root-relative paths that include the full path from root.

Returns:

  • (String)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The egress domain URL for stream delivery from MediaPackage.

Returns:

  • (String)


2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end

#utc_timingTypes::DashUtcTiming

Determines the type of UTC timing included in the DASH Media Presentation Description (MPD).



2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174

class GetDashManifestConfiguration < Struct.new(
  :manifest_name,
  :url,
  :manifest_window_seconds,
  :filter_configuration,
  :min_update_period_seconds,
  :min_buffer_time_seconds,
  :suggested_presentation_delay_seconds,
  :segment_template_format,
  :period_triggers,
  :scte_dash,
  :drm_signaling,
  :utc_timing,
  :profiles,
  :base_urls,
  :program_information,
  :dvb_settings,
  :compactness,
  :subtitle_configuration,
  :uri_path_type)
  SENSITIVE = []
  include Aws::Structure
end