Class: Aws::MediaPackageV2::Types::GetDashManifestConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetDashManifestConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Retrieve the DASH manifest configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_urls ⇒ Array<Types::DashBaseUrl>
The base URL to use for retrieving segments.
-
#compactness ⇒ String
The layout of the DASH manifest that MediaPackage produces.
-
#drm_signaling ⇒ String
Determines how the DASH manifest signals the DRM content.
-
#dvb_settings ⇒ Types::DashDvbSettings
For endpoints that use the DVB-DASH profile only.
-
#filter_configuration ⇒ Types::FilterConfiguration
Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.
-
#manifest_name ⇒ String
A short string that’s appended to the endpoint URL.
-
#manifest_window_seconds ⇒ Integer
The total duration (in seconds) of the manifest’s content.
-
#min_buffer_time_seconds ⇒ Integer
Minimum amount of content (in seconds) that a player must keep available in the buffer.
-
#min_update_period_seconds ⇒ Integer
Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest.
-
#period_triggers ⇒ Array<String>
A list of triggers that controls when AWS Elemental MediaPackage separates the MPEG-DASH manifest into multiple periods.
-
#profiles ⇒ Array<String>
The profile that the output is compliant with.
-
#program_information ⇒ Types::DashProgramInformation
Details about the content that you want MediaPackage to pass through in the manifest to the playback device.
-
#scte_dash ⇒ Types::ScteDash
The SCTE configuration.
-
#segment_template_format ⇒ String
Determines the type of variable used in the ‘media` URL of the `SegmentTemplate` tag in the manifest.
-
#subtitle_configuration ⇒ Types::DashSubtitleConfiguration
The configuration for DASH subtitles.
-
#suggested_presentation_delay_seconds ⇒ Integer
The amount of time (in seconds) that the player should be from the end of the manifest.
-
#uri_path_type ⇒ String
The type of path used in manifest URIs.
-
#url ⇒ String
The egress domain URL for stream delivery from MediaPackage.
-
#utc_timing ⇒ Types::DashUtcTiming
Determines the type of UTC timing included in the DASH Media Presentation Description (MPD).
Instance Attribute Details
#base_urls ⇒ Array<Types::DashBaseUrl>
The base URL to use for retrieving segments.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#compactness ⇒ String
The layout of the DASH manifest that MediaPackage produces. ‘STANDARD` indicates a default manifest, which is compacted. `NONE` indicates a full manifest.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#drm_signaling ⇒ String
Determines how the DASH manifest signals the DRM content.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#dvb_settings ⇒ Types::DashDvbSettings
For endpoints that use the DVB-DASH profile only. The font download and error reporting information that you want MediaPackage to pass through to the manifest.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#filter_configuration ⇒ Types::FilterConfiguration
Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#manifest_name ⇒ String
A short string that’s appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don’t enter a value, MediaPackage uses the default manifest name, index.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#manifest_window_seconds ⇒ Integer
The total duration (in seconds) of the manifest’s content.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#min_buffer_time_seconds ⇒ Integer
Minimum amount of content (in seconds) that a player must keep available in the buffer.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#min_update_period_seconds ⇒ Integer
Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#period_triggers ⇒ Array<String>
A list of triggers that controls when AWS Elemental MediaPackage separates the MPEG-DASH manifest into multiple periods. Leave this value empty to indicate that the manifest is contained all in one period. For more information about periods in the DASH manifest, see [Multi-period DASH in AWS Elemental MediaPackage].
[1]: docs.aws.amazon.com/mediapackage/latest/userguide/multi-period.html
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#profiles ⇒ Array<String>
The profile that the output is compliant with.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#program_information ⇒ Types::DashProgramInformation
Details about the content that you want MediaPackage to pass through in the manifest to the playback device.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#scte_dash ⇒ Types::ScteDash
The SCTE configuration.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#segment_template_format ⇒ String
Determines the type of variable used in the ‘media` URL of the `SegmentTemplate` tag in the manifest. Also specifies if segment timeline information is included in `SegmentTimeline` or `SegmentTemplate`.
Value description:
-
‘NUMBER_WITH_TIMELINE` - The `$Number$` variable is used in the `media` URL. The value of this variable is the sequential number of the segment. A full `SegmentTimeline` object is presented in each `SegmentTemplate`.
^
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#subtitle_configuration ⇒ Types::DashSubtitleConfiguration
The configuration for DASH subtitles.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#suggested_presentation_delay_seconds ⇒ Integer
The amount of time (in seconds) that the player should be from the end of the manifest.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#uri_path_type ⇒ String
The type of path used in manifest URIs. ‘LEAF` indicates leaf-relative paths. `ROOT` indicates root-relative paths that include the full path from root.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The egress domain URL for stream delivery from MediaPackage.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |
#utc_timing ⇒ Types::DashUtcTiming
Determines the type of UTC timing included in the DASH Media Presentation Description (MPD).
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2174 class GetDashManifestConfiguration < Struct.new( :manifest_name, :url, :manifest_window_seconds, :filter_configuration, :min_update_period_seconds, :min_buffer_time_seconds, :suggested_presentation_delay_seconds, :segment_template_format, :period_triggers, :scte_dash, :drm_signaling, :utc_timing, :profiles, :base_urls, :program_information, :dvb_settings, :compactness, :subtitle_configuration, :uri_path_type) SENSITIVE = [] include Aws::Structure end |