Class: Aws::MediaPackageV2::Types::GetHarvestJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetHarvestJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The response object containing the details of the requested harvest job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the harvest job.
-
#channel_group_name ⇒ String
The name of the channel group containing the channel associated with the harvest job.
-
#channel_name ⇒ String
The name of the channel associated with the harvest job.
-
#created_at ⇒ Time
The date and time when the harvest job was created.
-
#description ⇒ String
The description of the harvest job, if provided.
-
#destination ⇒ Types::Destination
The S3 destination where the harvested content is being placed.
-
#error_message ⇒ String
An error message if the harvest job encountered any issues.
-
#etag ⇒ String
The current version of the harvest job.
-
#harvest_job_name ⇒ String
The name of the harvest job.
-
#harvested_manifests ⇒ Types::HarvestedManifests
A list of manifests that are being or have been harvested.
-
#modified_at ⇒ Time
The date and time when the harvest job was last modified.
-
#origin_endpoint_name ⇒ String
The name of the origin endpoint associated with the harvest job.
-
#schedule_configuration ⇒ Types::HarvesterScheduleConfiguration
The configuration for when the harvest job is scheduled to run, including start and end times.
-
#status ⇒ String
The current status of the harvest job (e.g., QUEUED, IN_PROGRESS, CANCELLED, COMPLETED, FAILED).
-
#tags ⇒ Hash<String,String>
A collection of tags associated with the harvest job.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the harvest job.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name of the channel group containing the channel associated with the harvest job.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel associated with the harvest job.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the harvest job was created.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the harvest job, if provided.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::Destination
The S3 destination where the harvested content is being placed.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
An error message if the harvest job encountered any issues.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current version of the harvest job. Used for concurrency control.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#harvest_job_name ⇒ String
The name of the harvest job.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#harvested_manifests ⇒ Types::HarvestedManifests
A list of manifests that are being or have been harvested.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time when the harvest job was last modified.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name of the origin endpoint associated with the harvest job.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#schedule_configuration ⇒ Types::HarvesterScheduleConfiguration
The configuration for when the harvest job is scheduled to run, including start and end times.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the harvest job (e.g., QUEUED, IN_PROGRESS, CANCELLED, COMPLETED, FAILED).
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of tags associated with the harvest job.
2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2340 class GetHarvestJobResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :destination, :harvest_job_name, :harvested_manifests, :description, :schedule_configuration, :arn, :created_at, :modified_at, :status, :error_message, :etag, :tags) SENSITIVE = [] include Aws::Structure end |