Class: Aws::MediaPackageV2::Types::GetHarvestJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

The response object containing the details of the requested harvest job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the harvest job.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#channel_group_nameString

The name of the channel group containing the channel associated with the harvest job.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel associated with the harvest job.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the harvest job was created.

Returns:

  • (Time)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the harvest job, if provided.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#destinationTypes::Destination

The S3 destination where the harvested content is being placed.

Returns:



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

An error message if the harvest job encountered any issues.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The current version of the harvest job. Used for concurrency control.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#harvest_job_nameString

The name of the harvest job.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#harvested_manifestsTypes::HarvestedManifests

A list of manifests that are being or have been harvested.



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The date and time when the harvest job was last modified.

Returns:

  • (Time)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#origin_endpoint_nameString

The name of the origin endpoint associated with the harvest job.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configurationTypes::HarvesterScheduleConfiguration

The configuration for when the harvest job is scheduled to run, including start and end times.



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the harvest job (e.g., QUEUED, IN_PROGRESS, CANCELLED, COMPLETED, FAILED).

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of tags associated with the harvest job.

Returns:

  • (Hash<String,String>)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2297

class GetHarvestJobResponse < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :destination,
  :harvest_job_name,
  :harvested_manifests,
  :description,
  :schedule_configuration,
  :arn,
  :created_at,
  :modified_at,
  :status,
  :error_message,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end