Class: Aws::MediaPackageV2::Types::GetOriginEndpointPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::GetOriginEndpointPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cdn_auth_configuration ⇒ Types::CdnAuthConfiguration
The settings for using authorization headers between the MediaPackage endpoint and your CDN.
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint.
-
#policy ⇒ String
The policy assigned to the origin endpoint.
Instance Attribute Details
#cdn_auth_configuration ⇒ Types::CdnAuthConfiguration
The settings for using authorization headers between the MediaPackage endpoint and your CDN.
For information about CDN authorization, see [CDN authorization in Elemental MediaPackage] in the MediaPackage user guide.
[1]: docs.aws.amazon.com/mediapackage/latest/userguide/cdn-auth.html
2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2611 class GetOriginEndpointPolicyResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :policy, :cdn_auth_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2611 class GetOriginEndpointPolicyResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :policy, :cdn_auth_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2611 class GetOriginEndpointPolicyResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :policy, :cdn_auth_configuration) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.
2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2611 class GetOriginEndpointPolicyResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :policy, :cdn_auth_configuration) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The policy assigned to the origin endpoint.
2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2611 class GetOriginEndpointPolicyResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :policy, :cdn_auth_configuration) SENSITIVE = [] include Aws::Structure end |