Class: Aws::MediaPackageV2::Types::GetOriginEndpointResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) associated with the resource.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#container_typeString

The type of container attached to this origin endpoint.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the origin endpoint was created.

Returns:

  • (Time)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dash_manifestsArray<Types::GetDashManifestConfiguration>

A DASH manifest configuration.



2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description for your origin endpoint.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The current Entity Tag (ETag) associated with this resource. The entity tag can be used to safely make concurrent updates to the resource.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#force_endpoint_error_configurationTypes::ForceEndpointErrorConfiguration

The failover settings for the endpoint.



2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hls_manifestsArray<Types::GetHlsManifestConfiguration>

An HTTP live streaming (HLS) manifest configuration.



2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#low_latency_hls_manifestsArray<Types::GetLowLatencyHlsManifestConfiguration>

A low-latency HLS manifest configuration.



2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The date and time the origin endpoint was modified.

Returns:

  • (Time)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#mss_manifestsArray<Types::GetMssManifestConfiguration>

The Microsoft Smooth Streaming (MSS) manifest configurations associated with this origin endpoint.



2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#origin_endpoint_nameString

The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#reset_atTime

The time that the origin endpoint was last reset.

Returns:

  • (Time)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#segmentTypes::Segment

The segment configuration, including the segment name, duration, and other configuration values.

Returns:



2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#startover_window_secondsInteger

The size of the window (in seconds) to create a window of the live stream that’s available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window.

Returns:

  • (Integer)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The comma-separated list of tag key:value pairs assigned to the origin endpoint.

Returns:

  • (Hash<String,String>)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#uri_separatorString

The separator character used in generated URIs for this origin endpoint.

Returns:

  • (String)


2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 2784

class GetOriginEndpointResponse < Struct.new(
  :arn,
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :created_at,
  :modified_at,
  :reset_at,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end