Class: Aws::MediaPackageV2::Types::PutChannelPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::PutChannelPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#policy ⇒ String
The policy to attach to the specified channel.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
3620 3621 3622 3623 3624 3625 3626 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3620 class PutChannelPolicyRequest < Struct.new( :channel_group_name, :channel_name, :policy) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
3620 3621 3622 3623 3624 3625 3626 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3620 class PutChannelPolicyRequest < Struct.new( :channel_group_name, :channel_name, :policy) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The policy to attach to the specified channel.
3620 3621 3622 3623 3624 3625 3626 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3620 class PutChannelPolicyRequest < Struct.new( :channel_group_name, :channel_name, :policy) SENSITIVE = [] include Aws::Structure end |