Class: Aws::MediaPackageV2::Types::PutChannelPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


3451
3452
3453
3454
3455
3456
3457
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3451

class PutChannelPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


3451
3452
3453
3454
3455
3456
3457
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3451

class PutChannelPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#policyString

The policy to attach to the specified channel.

Returns:

  • (String)


3451
3452
3453
3454
3455
3456
3457
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3451

class PutChannelPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end