Class: Aws::MediaPackageV2::Types::PutOriginEndpointPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cdn_auth_configurationTypes::CdnAuthConfiguration

The settings for using authorization headers between the MediaPackage endpoint and your CDN.

For information about CDN authorization, see CDN authorization in Elemental MediaPackage in the MediaPackage user guide.



3638
3639
3640
3641
3642
3643
3644
3645
3646
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3638

class PutOriginEndpointPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :policy,
  :cdn_auth_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


3638
3639
3640
3641
3642
3643
3644
3645
3646
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3638

class PutOriginEndpointPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :policy,
  :cdn_auth_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


3638
3639
3640
3641
3642
3643
3644
3645
3646
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3638

class PutOriginEndpointPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :policy,
  :cdn_auth_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#origin_endpoint_nameString

The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.

Returns:

  • (String)


3638
3639
3640
3641
3642
3643
3644
3645
3646
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3638

class PutOriginEndpointPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :policy,
  :cdn_auth_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#policyString

The policy to attach to the specified origin endpoint.

Returns:

  • (String)


3638
3639
3640
3641
3642
3643
3644
3645
3646
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3638

class PutOriginEndpointPolicyRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :policy,
  :cdn_auth_configuration)
  SENSITIVE = []
  include Aws::Structure
end