Class: Aws::MediaPackageV2::Types::ResetChannelStateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name of the channel group that contains the channel that you are resetting.

Returns:

  • (String)


3524
3525
3526
3527
3528
3529
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3524

class ResetChannelStateRequest < Struct.new(
  :channel_group_name,
  :channel_name)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name of the channel that you are resetting.

Returns:

  • (String)


3524
3525
3526
3527
3528
3529
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3524

class ResetChannelStateRequest < Struct.new(
  :channel_group_name,
  :channel_name)
  SENSITIVE = []
  include Aws::Structure
end