Class: Aws::MediaPackageV2::Types::ResetChannelStateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::ResetChannelStateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the channel that you just reset.
-
#channel_group_name ⇒ String
The name of the channel group that contains the channel that you just reset.
-
#channel_name ⇒ String
The name of the channel that you just reset.
-
#reset_at ⇒ Time
The time that the channel was last reset.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the channel that you just reset.
3551 3552 3553 3554 3555 3556 3557 3558 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3551 class ResetChannelStateResponse < Struct.new( :channel_group_name, :channel_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name of the channel group that contains the channel that you just reset.
3551 3552 3553 3554 3555 3556 3557 3558 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3551 class ResetChannelStateResponse < Struct.new( :channel_group_name, :channel_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel that you just reset.
3551 3552 3553 3554 3555 3556 3557 3558 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3551 class ResetChannelStateResponse < Struct.new( :channel_group_name, :channel_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |
#reset_at ⇒ Time
The time that the channel was last reset.
3551 3552 3553 3554 3555 3556 3557 3558 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3551 class ResetChannelStateResponse < Struct.new( :channel_group_name, :channel_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |