Class: Aws::MediaPackageV2::Types::ResetOriginEndpointStateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::ResetOriginEndpointStateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the endpoint that you just reset.
-
#channel_group_name ⇒ String
The name of the channel group that contains the channel with the origin endpoint that you just reset.
-
#channel_name ⇒ String
The name of the channel with the origin endpoint that you just reset.
-
#origin_endpoint_name ⇒ String
The name of the origin endpoint that you just reset.
-
#reset_at ⇒ Time
The time that the origin endpoint was last reset.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the endpoint that you just reset.
3609 3610 3611 3612 3613 3614 3615 3616 3617 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609 class ResetOriginEndpointStateResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name of the channel group that contains the channel with the origin endpoint that you just reset.
3609 3610 3611 3612 3613 3614 3615 3616 3617 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609 class ResetOriginEndpointStateResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel with the origin endpoint that you just reset.
3609 3610 3611 3612 3613 3614 3615 3616 3617 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609 class ResetOriginEndpointStateResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name of the origin endpoint that you just reset.
3609 3610 3611 3612 3613 3614 3615 3616 3617 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609 class ResetOriginEndpointStateResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |
#reset_at ⇒ Time
The time that the origin endpoint was last reset.
3609 3610 3611 3612 3613 3614 3615 3616 3617 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3609 class ResetOriginEndpointStateResponse < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :arn, :reset_at) SENSITIVE = [] include Aws::Structure end |