Class: Aws::MediaPackageV2::Types::ScteDash
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::ScteDash
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
The SCTE configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_marker_dash ⇒ String
Choose how ad markers are included in the packaged content.
-
#scte_in_manifests ⇒ String
Controls which SCTE-35 events appear in DASH manifests.
Instance Attribute Details
#ad_marker_dash ⇒ String
Choose how ad markers are included in the packaged content. If you include ad markers in the content stream in your upstream encoders, then you need to inform MediaPackage what to do with the ad markers in the output.
Value description:
-
‘Binary` - The SCTE-35 marker is expressed as a hex-string (Base64 string) rather than full XML.
-
‘XML` - The SCTE marker is expressed fully in XML.
3730 3731 3732 3733 3734 3735 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3730 class ScteDash < Struct.new( :ad_marker_dash, :scte_in_manifests) SENSITIVE = [] include Aws::Structure end |
#scte_in_manifests ⇒ String
Controls which SCTE-35 events appear in DASH manifests. ‘ALL` includes all non-implicit SCTE-35 events. `MATCHES_FILTER` includes only events whose type matches the configured `ScteFilter`.
If you don’t specify a value, the default is ‘ALL`.
3730 3731 3732 3733 3734 3735 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3730 class ScteDash < Struct.new( :ad_marker_dash, :scte_in_manifests) SENSITIVE = [] include Aws::Structure end |