Class: Aws::MediaPackageV2::Types::ScteHls

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

The SCTE configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ad_marker_hlsString

Ad markers indicate when ads should be inserted during playback. If you include ad markers in the content stream in your upstream encoders, then you need to inform MediaPackage what to do with the ad markers in the output. Choose what you want MediaPackage to do with the ad markers.

Value description:

  • SCTE35_ENHANCED - Generate industry-standard CUE tag ad markers in HLS manifests based on SCTE-35 input messages from the input stream.

  • DATERANGE - Insert EXT-X-DATERANGE tags to signal ad and program transition events in TS and CMAF manifests. If you use DATERANGE, you must set a programDateTimeIntervalSeconds value of 1 or higher. To learn more about DATERANGE, see [SCTE-35 Ad Marker EXT-X-DATERANGE].

[1]: docs.aws.amazon.com/mediapackage/latest/ug/scte-35-ad-marker-ext-x-daterange.html

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3773

class ScteHls < Struct.new(
  :ad_marker_hls,
  :scte_in_manifests)
  SENSITIVE = []
  include Aws::Structure
end

#scte_in_manifestsString

Controls which SCTE-35 events appear in HLS manifests. ‘ALL` includes all non-implicit SCTE-35 events. `MATCHES_FILTER` includes only events whose type matches the configured `ScteFilter`.

If you don’t specify a value, the default is ‘ALL`.

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 3773

class ScteHls < Struct.new(
  :ad_marker_hls,
  :scte_in_manifests)
  SENSITIVE = []
  include Aws::Structure
end