Class: Aws::MediaPackageV2::Types::UpdateChannelGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::UpdateChannelGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#description ⇒ String
Any descriptive information that you want to add to the channel group for future identification purposes.
-
#etag ⇒ String
The expected current Entity Tag (ETag) for the resource.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
4063 4064 4065 4066 4067 4068 4069 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4063 class UpdateChannelGroupRequest < Struct.new( :channel_group_name, :etag, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Any descriptive information that you want to add to the channel group for future identification purposes.
4063 4064 4065 4066 4067 4068 4069 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4063 class UpdateChannelGroupRequest < Struct.new( :channel_group_name, :etag, :description) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The expected current Entity Tag (ETag) for the resource. If the specified ETag does not match the resource’s current entity tag, the update request will be rejected.
4063 4064 4065 4066 4067 4068 4069 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4063 class UpdateChannelGroupRequest < Struct.new( :channel_group_name, :etag, :description) SENSITIVE = [] include Aws::Structure end |