Class: Aws::MediaPackageV2::Types::UpdateChannelGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


4020
4021
4022
4023
4024
4025
4026
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4020

class UpdateChannelGroupRequest < Struct.new(
  :channel_group_name,
  :etag,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Any descriptive information that you want to add to the channel group for future identification purposes.

Returns:

  • (String)


4020
4021
4022
4023
4024
4025
4026
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4020

class UpdateChannelGroupRequest < Struct.new(
  :channel_group_name,
  :etag,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The expected current Entity Tag (ETag) for the resource. If the specified ETag does not match the resource’s current entity tag, the update request will be rejected.

Returns:

  • (String)


4020
4021
4022
4023
4024
4025
4026
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4020

class UpdateChannelGroupRequest < Struct.new(
  :channel_group_name,
  :etag,
  :description)
  SENSITIVE = []
  include Aws::Structure
end