Class: Aws::MediaPackageV2::Types::UpdateChannelGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::UpdateChannelGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource.
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#created_at ⇒ Time
The date and time the channel group was created.
-
#description ⇒ String
The description for your channel group.
-
#egress_domain ⇒ String
The output domain where the source stream is sent.
-
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource.
-
#modified_at ⇒ Time
The date and time the channel group was modified.
-
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the channel group.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) associated with the resource.
4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4069 class UpdateChannelGroupResponse < Struct.new( :channel_group_name, :arn, :egress_domain, :created_at, :modified_at, :description, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4069 class UpdateChannelGroupResponse < Struct.new( :channel_group_name, :arn, :egress_domain, :created_at, :modified_at, :description, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the channel group was created.
4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4069 class UpdateChannelGroupResponse < Struct.new( :channel_group_name, :arn, :egress_domain, :created_at, :modified_at, :description, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for your channel group.
4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4069 class UpdateChannelGroupResponse < Struct.new( :channel_group_name, :arn, :egress_domain, :created_at, :modified_at, :description, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#egress_domain ⇒ String
The output domain where the source stream is sent. Integrate the domain with a downstream CDN (such as Amazon CloudFront) or playback device.
4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4069 class UpdateChannelGroupResponse < Struct.new( :channel_group_name, :arn, :egress_domain, :created_at, :modified_at, :description, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource. The entity tag can be used to safely make concurrent updates to the resource.
4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4069 class UpdateChannelGroupResponse < Struct.new( :channel_group_name, :arn, :egress_domain, :created_at, :modified_at, :description, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the channel group was modified.
4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4069 class UpdateChannelGroupResponse < Struct.new( :channel_group_name, :arn, :egress_domain, :created_at, :modified_at, :description, :etag, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the channel group.
4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4069 class UpdateChannelGroupResponse < Struct.new( :channel_group_name, :arn, :egress_domain, :created_at, :modified_at, :description, :etag, :tags) SENSITIVE = [] include Aws::Structure end |