Class: Aws::MediaPackageV2::Types::UpdateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119

class UpdateChannelRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :etag,
  :description,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119

class UpdateChannelRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :etag,
  :description,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Any descriptive information that you want to add to the channel for future identification purposes.

Returns:

  • (String)


4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119

class UpdateChannelRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :etag,
  :description,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The expected current Entity Tag (ETag) for the resource. If the specified ETag does not match the resource’s current entity tag, the update request will be rejected.

Returns:

  • (String)


4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119

class UpdateChannelRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :etag,
  :description,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#input_switch_configurationTypes::InputSwitchConfiguration

The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive. This setting is valid only when ‘InputType` is `CMAF`.



4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119

class UpdateChannelRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :etag,
  :description,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#output_header_configurationTypes::OutputHeaderConfiguration

The settings for what common media server data (CMSD) headers AWS Elemental MediaPackage includes in responses to the CDN. This setting is valid only when ‘InputType` is `CMAF`.



4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119

class UpdateChannelRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :etag,
  :description,
  :input_switch_configuration,
  :output_header_configuration)
  SENSITIVE = []
  include Aws::Structure
end