Class: Aws::MediaPackageV2::Types::UpdateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::UpdateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#description ⇒ String
Any descriptive information that you want to add to the channel for future identification purposes.
-
#etag ⇒ String
The expected current Entity Tag (ETag) for the resource.
-
#input_switch_configuration ⇒ Types::InputSwitchConfiguration
The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive.
-
#output_header_configuration ⇒ Types::OutputHeaderConfiguration
The settings for what common media server data (CMSD) headers AWS Elemental MediaPackage includes in responses to the CDN.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119 class UpdateChannelRequest < Struct.new( :channel_group_name, :channel_name, :etag, :description, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119 class UpdateChannelRequest < Struct.new( :channel_group_name, :channel_name, :etag, :description, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Any descriptive information that you want to add to the channel for future identification purposes.
4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119 class UpdateChannelRequest < Struct.new( :channel_group_name, :channel_name, :etag, :description, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The expected current Entity Tag (ETag) for the resource. If the specified ETag does not match the resource’s current entity tag, the update request will be rejected.
4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119 class UpdateChannelRequest < Struct.new( :channel_group_name, :channel_name, :etag, :description, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#input_switch_configuration ⇒ Types::InputSwitchConfiguration
The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive. This setting is valid only when ‘InputType` is `CMAF`.
4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119 class UpdateChannelRequest < Struct.new( :channel_group_name, :channel_name, :etag, :description, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |
#output_header_configuration ⇒ Types::OutputHeaderConfiguration
The settings for what common media server data (CMSD) headers AWS Elemental MediaPackage includes in responses to the CDN. This setting is valid only when ‘InputType` is `CMAF`.
4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4119 class UpdateChannelRequest < Struct.new( :channel_group_name, :channel_name, :etag, :description, :input_switch_configuration, :output_header_configuration) SENSITIVE = [] include Aws::Structure end |