Class: Aws::MediaPackageV2::Types::UpdateOriginEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackagev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_group_nameString

The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.

Returns:

  • (String)


4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#channel_nameString

The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.

Returns:

  • (String)


4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#container_typeString

The type of container attached to this origin endpoint. A container type is a file format that encapsulates one or more media streams, such as audio and video, into a single file.

Returns:

  • (String)


4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#dash_manifestsArray<Types::CreateDashManifestConfiguration>

A DASH manifest configuration.



4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Any descriptive information that you want to add to the origin endpoint for future identification purposes.

Returns:

  • (String)


4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#etagString

The expected current Entity Tag (ETag) for the resource. If the specified ETag does not match the resource’s current entity tag, the update request will be rejected.

Returns:

  • (String)


4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#force_endpoint_error_configurationTypes::ForceEndpointErrorConfiguration

The failover settings for the endpoint.



4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#hls_manifestsArray<Types::CreateHlsManifestConfiguration>

An HTTP live streaming (HLS) manifest configuration.



4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#low_latency_hls_manifestsArray<Types::CreateLowLatencyHlsManifestConfiguration>

A low-latency HLS manifest configuration.



4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#mss_manifestsArray<Types::CreateMssManifestConfiguration>

A list of Microsoft Smooth Streaming (MSS) manifest configurations to update for the origin endpoint. This replaces the existing MSS manifest configurations.



4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#origin_endpoint_nameString

The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.

Returns:

  • (String)


4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#segmentTypes::Segment

The segment configuration, including the segment name, duration, and other configuration values.

Returns:



4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#startover_window_secondsInteger

The size of the window (in seconds) to create a window of the live stream that’s available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window. The maximum startover window is 1,209,600 seconds (14 days).

Returns:

  • (Integer)


4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end

#uri_separatorString

The separator character to use in generated URIs for this origin endpoint. This setting applies to all manifest types on the endpoint. If you don’t specify a value in the update request, the current value is preserved.

Returns:

  • (String)


4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4370

class UpdateOriginEndpointRequest < Struct.new(
  :channel_group_name,
  :channel_name,
  :origin_endpoint_name,
  :container_type,
  :segment,
  :description,
  :startover_window_seconds,
  :hls_manifests,
  :low_latency_hls_manifests,
  :dash_manifests,
  :mss_manifests,
  :force_endpoint_error_configuration,
  :uri_separator,
  :etag)
  SENSITIVE = []
  include Aws::Structure
end