Class: Aws::MediaPackageV2::Types::UpdateOriginEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::UpdateOriginEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#container_type ⇒ String
The type of container attached to this origin endpoint.
-
#dash_manifests ⇒ Array<Types::CreateDashManifestConfiguration>
A DASH manifest configuration.
-
#description ⇒ String
Any descriptive information that you want to add to the origin endpoint for future identification purposes.
-
#etag ⇒ String
The expected current Entity Tag (ETag) for the resource.
-
#force_endpoint_error_configuration ⇒ Types::ForceEndpointErrorConfiguration
The failover settings for the endpoint.
-
#hls_manifests ⇒ Array<Types::CreateHlsManifestConfiguration>
An HTTP live streaming (HLS) manifest configuration.
-
#low_latency_hls_manifests ⇒ Array<Types::CreateLowLatencyHlsManifestConfiguration>
A low-latency HLS manifest configuration.
-
#mss_manifests ⇒ Array<Types::CreateMssManifestConfiguration>
A list of Microsoft Smooth Streaming (MSS) manifest configurations to update for the origin endpoint.
-
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint.
-
#segment ⇒ Types::Segment
The segment configuration, including the segment name, duration, and other configuration values.
-
#startover_window_seconds ⇒ Integer
The size of the window (in seconds) to create a window of the live stream that’s available for on-demand viewing.
-
#uri_separator ⇒ String
The separator character to use in generated URIs for this origin endpoint.
Instance Attribute Details
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#container_type ⇒ String
The type of container attached to this origin endpoint. A container type is a file format that encapsulates one or more media streams, such as audio and video, into a single file.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#dash_manifests ⇒ Array<Types::CreateDashManifestConfiguration>
A DASH manifest configuration.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Any descriptive information that you want to add to the origin endpoint for future identification purposes.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The expected current Entity Tag (ETag) for the resource. If the specified ETag does not match the resource’s current entity tag, the update request will be rejected.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#force_endpoint_error_configuration ⇒ Types::ForceEndpointErrorConfiguration
The failover settings for the endpoint.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#hls_manifests ⇒ Array<Types::CreateHlsManifestConfiguration>
An HTTP live streaming (HLS) manifest configuration.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#low_latency_hls_manifests ⇒ Array<Types::CreateLowLatencyHlsManifestConfiguration>
A low-latency HLS manifest configuration.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#mss_manifests ⇒ Array<Types::CreateMssManifestConfiguration>
A list of Microsoft Smooth Streaming (MSS) manifest configurations to update for the origin endpoint. This replaces the existing MSS manifest configurations.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#segment ⇒ Types::Segment
The segment configuration, including the segment name, duration, and other configuration values.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#startover_window_seconds ⇒ Integer
The size of the window (in seconds) to create a window of the live stream that’s available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window. The maximum startover window is 1,209,600 seconds (14 days).
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |
#uri_separator ⇒ String
The separator character to use in generated URIs for this origin endpoint. This setting applies to all manifest types on the endpoint. If you don’t specify a value in the update request, the current value is preserved.
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4296 class UpdateOriginEndpointRequest < Struct.new( :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :dash_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag) SENSITIVE = [] include Aws::Structure end |