Class: Aws::MediaPackageV2::Types::UpdateOriginEndpointResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaPackageV2::Types::UpdateOriginEndpointResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mediapackagev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN associated with the resource.
-
#channel_group_name ⇒ String
The name that describes the channel group.
-
#channel_name ⇒ String
The name that describes the channel.
-
#container_type ⇒ String
The type of container attached to this origin endpoint.
-
#created_at ⇒ Time
The date and time the origin endpoint was created.
-
#dash_manifests ⇒ Array<Types::GetDashManifestConfiguration>
A DASH manifest configuration.
-
#description ⇒ String
The description of the origin endpoint.
-
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource.
-
#force_endpoint_error_configuration ⇒ Types::ForceEndpointErrorConfiguration
The failover settings for the endpoint.
-
#hls_manifests ⇒ Array<Types::GetHlsManifestConfiguration>
An HTTP live streaming (HLS) manifest configuration.
-
#low_latency_hls_manifests ⇒ Array<Types::GetLowLatencyHlsManifestConfiguration>
A low-latency HLS manifest configuration.
-
#modified_at ⇒ Time
The date and time the origin endpoint was modified.
-
#mss_manifests ⇒ Array<Types::GetMssManifestConfiguration>
The updated Microsoft Smooth Streaming (MSS) manifest configurations for this origin endpoint.
-
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint.
-
#segment ⇒ Types::Segment
The segment configuration, including the segment name, duration, and other configuration values.
-
#startover_window_seconds ⇒ Integer
The size of the window (in seconds) to create a window of the live stream that’s available for on-demand viewing.
-
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the origin endpoint.
-
#uri_separator ⇒ String
The separator character used in generated URIs for this origin endpoint.
Instance Attribute Details
#arn ⇒ String
The ARN associated with the resource.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#channel_group_name ⇒ String
The name that describes the channel group. The name is the primary identifier for the channel group, and must be unique for your account in the AWS Region.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name that describes the channel. The name is the primary identifier for the channel, and must be unique for your account in the AWS Region and channel group.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#container_type ⇒ String
The type of container attached to this origin endpoint.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the origin endpoint was created.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#dash_manifests ⇒ Array<Types::GetDashManifestConfiguration>
A DASH manifest configuration.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the origin endpoint.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#etag ⇒ String
The current Entity Tag (ETag) associated with this resource. The entity tag can be used to safely make concurrent updates to the resource.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#force_endpoint_error_configuration ⇒ Types::ForceEndpointErrorConfiguration
The failover settings for the endpoint.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#hls_manifests ⇒ Array<Types::GetHlsManifestConfiguration>
An HTTP live streaming (HLS) manifest configuration.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#low_latency_hls_manifests ⇒ Array<Types::GetLowLatencyHlsManifestConfiguration>
A low-latency HLS manifest configuration.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the origin endpoint was modified.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#mss_manifests ⇒ Array<Types::GetMssManifestConfiguration>
The updated Microsoft Smooth Streaming (MSS) manifest configurations for this origin endpoint.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#origin_endpoint_name ⇒ String
The name that describes the origin endpoint. The name is the primary identifier for the origin endpoint, and and must be unique for your account in the AWS Region and channel.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#segment ⇒ Types::Segment
The segment configuration, including the segment name, duration, and other configuration values.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#startover_window_seconds ⇒ Integer
The size of the window (in seconds) to create a window of the live stream that’s available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The comma-separated list of tag key:value pairs assigned to the origin endpoint.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |
#uri_separator ⇒ String
The separator character used in generated URIs for this origin endpoint.
4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-mediapackagev2/types.rb', line 4403 class UpdateOriginEndpointResponse < Struct.new( :arn, :channel_group_name, :channel_name, :origin_endpoint_name, :container_type, :segment, :created_at, :modified_at, :description, :startover_window_seconds, :hls_manifests, :low_latency_hls_manifests, :mss_manifests, :force_endpoint_error_configuration, :uri_separator, :etag, :tags, :dash_manifests) SENSITIVE = [] include Aws::Structure end |