Class: Aws::MediaPackageV2::Waiters::HarvestJobFinished
- Inherits:
-
Object
- Object
- Aws::MediaPackageV2::Waiters::HarvestJobFinished
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-mediapackagev2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ HarvestJobFinished
constructor
A new instance of HarvestJobFinished.
-
#wait(params = {}) ⇒ Types::GetHarvestJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ HarvestJobFinished
Returns a new instance of HarvestJobFinished.
84 85 |
# File 'lib/aws-sdk-mediapackagev2/waiters.rb', line 84
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
134 135 136 |
# File 'lib/aws-sdk-mediapackagev2/waiters.rb', line 134 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetHarvestJobResponse
Returns a response object which responds to the following methods:
- #channel_group_name => String
- #channel_name => String
- #origin_endpoint_name => String
- #destination => Types::Destination
- #harvest_job_name => String
- #harvested_manifests => Types::HarvestedManifests
- #description => String
- #schedule_configuration => Types::HarvesterScheduleConfiguration
- #arn => String
- #created_at => Time
- #modified_at => Time
- #status => String
- #error_message => String
- #etag => String
- #tags => Hash<String,String>
129 |
# File 'lib/aws-sdk-mediapackagev2/waiters.rb', line 129
def wait: (
|